@@ -91,6 +91,8 @@ class APIESBlueprint(Blueprint):
         )
 
         app.config['ES_CLIENT'] = es_client
+        self.json = demjson.JSON()
+        self.json.set_hook('decode_float', float)
 
     def search_handler(self, types):
         es_client = current_app.config['ES_CLIENT']
@@ -111,6 +113,8 @@ class APIESBlueprint(Blueprint):
             snippets = [x.strip() for x in request.values.get('snippets', '').split(',') if x]
             match_type = request.values.get('match_type')
             match_operator = request.values.get('match_operator')
+            score_threshold = int(request.values.get('minscore', 0))
+
             result = self.controllers.search(
                 es_client, types_formatted, search_term,
                 from_date=from_date,
@@ -121,7 +125,7 @@ class APIESBlueprint(Blueprint):
                 lookup=lookup,
                 term_context=term_context,
                 extra=extra,
-                score_threshold=0, 
+                score_threshold=score_threshold, 
                 sort_fields=order,
                 highlight=highlight,
                 snippets=snippets,
@@ -157,6 +161,7 @@ class APIESBlueprint(Blueprint):
             filters = request.values.get('filter')
             lookup = request.values.get('lookup')
             order = request.values.get('order')
+            score_threshold = int(request.values.get('minscore', 0))
 
             # Get the query results
             result = self.controllers.search(es_client,
@@ -170,7 +175,7 @@ class APIESBlueprint(Blueprint):
                                              lookup,
                                              term_context,
                                              extra,
-                                             score_threshold=0,
+                                             score_threshold=score_threshold,
                                              sort_fields=order)
 
         except Exception as e:
@@ -220,7 +225,7 @@ class APIESBlueprint(Blueprint):
 
         config = request.values.get('config')
         try:
-            config = demjson.decode(config)
+            config = self.json.decode(config)
             search_term = request.values.get('q')
             from_date = request.values.get('from_date')
             to_date = request.values.get('to_date')
